<?php
$lan = array(
 'Deleting' => 'Apagando',
 'Done' => 'Conclu&iacute;do',
 'RSS source' => 'fonte RSS',
 'delete' => 'apagar',
 'n/a' => 'n/d',
 'No lists available, use Add to add one' => 'Nenhuma lista encontrada, use Adicionar para incluir uma',
 'No' => 'No.',
 'Name' => 'Nome',
 'Order' => 'Ordem',
 'Functions' => 'Fun&ccedil;&otilde;es',
 'Active' => 'Ativa',
 'Owner' => 'Administrador',
 'Save Changes' => 'Salvar Altera&ccedil;&otilde;es',
 'Add a list' => 'Adicionar uma lista',
 'members' => 'Membros',
 '(view items)' => '(Exibir &Iacute;tens)',
 'edit' => 'editar',
 'view members' => 'exibir membros',
);
?>
